#line 2 "gabc/gabc-score-determination-l.c"

#line 4 "gabc/gabc-score-determination-l.c"

#define  YY_INT_ALIGNED long int

/* A lexical scanner generated by flex */

#define yy_create_buffer gabc_score_determination__create_buffer
#define yy_delete_buffer gabc_score_determination__delete_buffer
#define yy_flex_debug gabc_score_determination__flex_debug
#define yy_init_buffer gabc_score_determination__init_buffer
#define yy_flush_buffer gabc_score_determination__flush_buffer
#define yy_load_buffer_state gabc_score_determination__load_buffer_state
#define yy_switch_to_buffer gabc_score_determination__switch_to_buffer
#define yyin gabc_score_determination_in
#define yyleng gabc_score_determination_leng
#define yylex gabc_score_determination_lex
#define yylineno gabc_score_determination_lineno
#define yyout gabc_score_determination_out
#define yyrestart gabc_score_determination_restart
#define yytext gabc_score_determination_text
#define yywrap gabc_score_determination_wrap
#define yyalloc gabc_score_determination_alloc
#define yyrealloc gabc_score_determination_realloc
#define yyfree gabc_score_determination_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gabc_score_determination_restart(gabc_score_determination_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t gabc_score_determination_leng;

extern FILE *gabc_score_determination_in, *gabc_score_determination_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gabc_score_determination_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gabc_score_determination_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gabc_score_determination_restart()), so that the user can continue scanning by
	 * just pointing gabc_score_determination_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gabc_score_determination_text is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t gabc_score_determination_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gabc_score_determination_wrap()'s to do buffer switches
 * instead of setting up a fresh gabc_score_determination_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gabc_score_determination_restart (FILE *input_file  );
void gabc_score_determination__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gabc_score_determination__create_buffer (FILE *file,int size  );
void gabc_score_determination__delete_buffer (YY_BUFFER_STATE b  );
void gabc_score_determination__flush_buffer (YY_BUFFER_STATE b  );
void gabc_score_determination_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void gabc_score_determination_pop_buffer_state (void );

static void gabc_score_determination_ensure_buffer_stack (void );
static void gabc_score_determination__load_buffer_state (void );
static void gabc_score_determination__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gabc_score_determination__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gabc_score_determination__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gabc_score_determination__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gabc_score_determination__scan_bytes (yyconst char *bytes,yy_size_t len  );

void *gabc_score_determination_alloc (yy_size_t  );
void *gabc_score_determination_realloc (void *,yy_size_t  );
void gabc_score_determination_free (void *  );

#define yy_new_buffer gabc_score_determination__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gabc_score_determination_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gabc_score_determination__create_buffer(gabc_score_determination_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gabc_score_determination_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gabc_score_determination__create_buffer(gabc_score_determination_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define gabc_score_determination_wrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *gabc_score_determination_in = (FILE *) 0, *gabc_score_determination_out = (FILE *) 0;

typedef int yy_state_type;

extern int gabc_score_determination_lineno;

int gabc_score_determination_lineno = 1;

extern char *gabc_score_determination_text;
#define yytext_ptr gabc_score_determination_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gabc_score_determination_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	gabc_score_determination_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 70
#define YY_END_OF_BUFFER 71
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int32_t yy_accept[292] =
    {   0,
        0,    1,    7,    7,    0,    0,   65,   65,   46,   46,
       52,   52,   49,   49,    5,    5,   57,   57,   71,   25,
       69,   25,   23,    6,   23,   23,   23,   23,   23,   23,
       23,   23,   23,    2,    2,    3,    3,    1,    7,    7,
       70,   26,   47,   64,   27,   53,   62,   63,   54,   55,
       65,   67,   66,   46,   53,   52,   53,   49,   48,    5,
        4,   57,   53,    0,    0,   23,    6,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,    2,    1,
        7,    7,    0,    7,    7,    0,    7,    8,    0,   26,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,   65,   68,   46,    0,    0,   52,    0,   49,
       48,    5,    4,   57,    0,   24,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,    7,
        0,    0,    0,   38,   36,   42,    0,   30,    0,    0,
        0,    0,    0,   50,   61,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   23,   23,    0,   23,   23,   23,
       14,   23,   10,   23,   23,   23,    0,    0,    0,   59,
        0,   40,   44,   32,   34,   39,   37,   43,   31,    0,
        0,    0,    0,   51,    0,   23,   23,   23,    0,   23,
       23,    0,    0,   23,   23,   23,   60,    0,   56,    0,

       41,   45,   33,   35,    0,   23,   18,    9,   23,   23,
       23,   23,   23,   23,   23,    0,    0,    0,   28,   58,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       29,   23,   23,    0,   19,   23,   23,   23,    0,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       17,   23,   23,   23,   23,   21,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   20,   23,   23,   23,   23,
       23,   23,   23,   13,   23,   15,   23,   23,   12,   23,
       23,   23,   23,   23,   11,   16,   23,   23,   23,   22,
        0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    1,    6,    1,    7,    1,    1,    8,
        9,    1,    1,    1,   10,    1,   11,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,   14,   15,
        1,   16,    1,    1,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       18,    1,   19,    1,   17,    1,   20,   21,   22,   23,

       24,   25,   26,   27,   28,   17,   17,   29,   30,   31,
       32,   33,   17,   34,   35,   36,   37,   38,   17,   17,
       39,   17,   40,   41,   42,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   43,    1,    1,    1,
       44,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,   45,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[46] =
    {   0,
        1,    1,    2,    2,    1,    1,    3,    3,    4,    5,
        1,    6,    1,    7,    8,    1,    6,    3,    3,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    9,
        4,    9,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_base[313] =
    {   0,
        0,   43,   48,   50,   82,  118,   39,   50,   41,   42,
      635,  634,   57,   62,   64,   66,  633,  632,  646,  651,
      651,  638,  634,  638,   48,   53,   83,   45,   84,   63,
       86,   64,   95,   68,  104,  651,  635,   66,  109,  115,
      131,    0,  651,  651,  651,  150,  630,  651,  651,  651,
        0,  136,  651,    0,  131,    0,  629,    0,  111,    0,
      117,    0,  628,  140,    0,  628,  651,   68,  117,  138,
      136,  122,  142,  139,  146,  149,  158,  144,  162,  139,
      188,  190,  192,  623,  194,    0,  196,  176,  208,    0,
      183,  607,  619,  618,  185,  617,  603,  183,  595,  601,

      613,  609,    0,  215,    0,  202,  611,    0,  588,    0,
      224,    0,  228,    0,  605,  231,  614,  193,  219,  613,
      199,  179,  226,   92,  231,  230,  232,  234,  233,  608,
      584,  591,  583,  651,  651,  651,  602,  651,  596,  600,
      599,  598,  597,  651,  651,  596,  595,  594,  593,  223,
      572,  578,  590,  576,  237,  238,  574,  593,  241,  239,
      592,  591,  590,  240,  247,  249,  583,  577,  581,  651,
      576,  651,  651,  651,  651,  651,  651,  651,  651,  579,
      578,  577,  576,  651,  555,  245,  250,  251,  568,  262,
      265,  256,  560,  254,  578,  577,  651,  566,  651,  569,

      651,  651,  651,  651,  566,  256,  564,  549,  267,  268,
      270,  273,  271,  277,  278,  528,  518,  511,  651,  651,
      279,  283,  511,  280,  284,  285,  288,  509,  290,  292,
      651,  296,  300,  377,  400,  301,  302,  305,  373,  304,
      307,  311,  313,  308,  317,  315,  314,  321,  322,  324,
      394,  323,  325,  326,  335,  392,  340,  333,  336,  343,
      344,  342,  346,  348,  347,  387,  349,  355,  352,  364,
      368,  367,  370,  385,  371,  382,  372,  374,  203,  375,
      376,  377,  380,  378,  165,  159,  381,  379,  384,  120,
      651,  415,  424,  433,  442,  451,  460,  469,  478,  483,

      489,  498,  507,  516,  523,  532,  539,  548,  557,  566,
       69,  575
    } ;

static yyconst flex_int32_t yy_def[313] =
    {   0,
      291,    1,  292,  292,  293,  293,  294,  294,  295,  295,
      296,  296,  297,  297,  298,  298,  299,  299,  291,  291,
      291,  291,  300,  291,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  291,  291,  291,  291,  291,  301,  302,
      303,  304,  291,  291,  291,  291,  291,  291,  291,  291,
      305,  291,  291,  306,   46,  307,  291,  308,  291,  309,
      291,  310,  291,  291,  311,  300,  291,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  291,  291,
      301,  302,  303,  302,  302,  312,  303,  291,  291,  304,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,

      291,  291,  305,  291,  306,  291,  291,  307,  291,  308,
      291,  309,  291,  310,  291,  291,  311,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  312,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  300,  300,  311,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  300,  300,  311,  311,  300,
      300,  311,  311,  300,  300,  300,  291,  291,  291,  291,

      291,  291,  291,  291,  291,  300,  300,  311,  311,  300,
      300,  311,  311,  311,  300,  311,  311,  291,  291,  291,
      300,  311,  300,  300,  311,  311,  311,  300,  311,  311,
      291,  300,  311,  311,  300,  311,  311,  311,  311,  311,
      311,  300,  311,  311,  311,  311,  311,  311,  311,  311,
      300,  311,  311,  311,  311,  311,  311,  311,  311,  311,
      311,  311,  311,  311,  311,  311,  311,  311,  311,  311,
      311,  311,  311,  311,  311,  311,  311,  311,  311,  311,
      311,  311,  311,  311,  311,  311,  311,  311,  311,  311,
        0,  291,  291,  291,  291,  291,  291,  291,  291,  291,

      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291
    } ;

static yyconst flex_int32_t yy_nxt[697] =
    {   0,
       20,   20,   21,   20,   20,   20,   22,   20,   20,   20,
       20,   23,   24,   20,   20,   20,   23,   20,   20,   25,
       23,   23,   26,   23,   23,   27,   23,   28,   29,   30,
       31,   32,   23,   23,   33,   23,   23,   23,   23,   20,
       20,   20,   20,   20,   20,   34,   35,   52,   36,   37,
       40,   40,   40,   40,   65,   55,   55,   65,   52,   59,
       59,   41,   65,   41,   59,   59,   61,   61,   61,   61,
       79,   79,   65,   65,  117,   72,   70,   65,   68,   53,
       49,   49,   50,   50,   69,   38,   38,   38,   43,   44,
       53,   45,   65,   65,   74,   65,   46,   76,  118,   47,

       48,   65,   71,   73,   65,   75,   79,   79,   80,   80,
       80,   82,   82,  111,  111,  161,   77,   85,   85,  113,
      113,   49,   83,   50,   43,   44,   65,   45,   86,   65,
       78,   65,   46,   88,   88,   47,   48,  104,  104,  104,
      104,  106,  116,  116,   89,   65,   64,   65,   65,  122,
      291,   65,  119,   65,  107,   65,  121,   49,   65,   50,
       91,  124,  120,  129,   79,   79,  125,   65,   65,   92,
       93,   94,  123,   95,   65,  126,  127,   96,   88,   88,
       97,   80,   80,   80,   98,   99,  100,  101,   65,  128,
       82,   82,   85,   85,  291,  291,   85,   85,   82,   82,

      136,   83,   65,   86,  140,  291,  131,   86,   65,   83,
       88,   88,   65,  132,  159,  141,  104,  104,  104,  104,
      158,  137,  146,  147,  155,  148,  111,  111,   65,  149,
      113,  113,  132,  116,  116,   65,  150,  151,  152,   65,
       65,   65,   65,   65,  180,  156,   65,   65,   65,   65,
       65,  160,  162,  163,   65,  181,   65,  166,   65,   65,
       65,  194,  208,   65,  206,   65,  164,  165,  190,  187,
      195,   65,  186,  196,   65,  191,   65,   65,  212,   65,
       65,  210,   65,  207,  211,  213,   65,   65,   65,   65,
      215,  221,   65,   65,   65,  224,  223,   65,  222,   65,

      225,   65,  226,  235,  227,   65,  232,  237,  236,   65,
       65,   65,  228,   65,   65,  233,   65,   65,  238,  241,
       65,  240,   65,   65,   65,  245,   65,  242,  247,  246,
       65,   65,   65,   65,   65,   65,  249,  250,  243,  255,
      254,  251,   65,  253,   65,   65,  252,  259,  256,   65,
      260,   65,   65,   65,  257,   65,   65,   65,   65,  262,
      258,   65,  263,  261,   65,  269,  265,  264,  267,  270,
      266,  271,  268,   65,  272,  273,   65,   65,  274,   65,
       65,   65,  275,   65,   65,   65,   65,   65,   65,   65,
       65,   65,  278,   65,   65,  284,   65,  276,  277,  286,

      282,   65,  283,   65,  248,  279,  280,  281,  288,   65,
      289,  244,  285,  287,  290,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   66,   66,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   84,   84,

       84,   84,   84,   84,   84,   84,   84,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   90,   90,  239,   90,
      234,   90,   90,  103,  103,  103,  231,  103,  103,  103,
      103,  103,  105,  105,  105,  105,  105,  105,  105,  108,
      108,  108,  108,  108,  108,  108,  230,  108,  110,  229,
      110,  110,  110,  110,  110,  110,  110,  112,   65,  112,
      112,  112,  112,  112,  112,  112,  114,  114,  114,  114,
      114,  114,  114,   65,  114,  130,  130,  130,  130,  130,
      130,  220,  130,  130,  219,  218,  217,  216,  214,  209,
      205,  204,  203,  202,  201,  200,  199,  198,  197,   65,

      193,  192,  189,  188,  185,  184,  183,  182,  179,  178,
      177,  176,  175,  174,  173,  172,  171,  170,  169,  168,
      167,   86,  157,   65,  154,  153,  136,  145,  144,  143,
      142,  139,  138,  135,  134,  133,   86,   65,  115,  109,
      102,   64,   67,   65,   64,  291,   63,   63,   57,   57,
       19,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291

    } ;

static yyconst flex_int32_t yy_chk[697] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    2,    7,    2,    2,
        3,    3,    4,    4,   28,    9,   10,   25,    8,   13,
       13,    3,   26,    4,   14,   14,   15,   15,   16,   16,
       34,   34,   30,   32,  311,   28,   26,   68,   25,    7,
        9,   10,    9,   10,   25,    2,    2,    2,    5,    5,
        8,    5,   27,   29,   30,   31,    5,   32,   68,    5,

        5,  124,   27,   29,   33,   31,   35,   35,   38,   38,
       38,   39,   39,   59,   59,  124,   33,   40,   40,   61,
       61,    5,   39,    5,    6,    6,   69,    6,   40,  290,
       33,   72,    6,   41,   41,    6,    6,   52,   52,   52,
       52,   55,   64,   64,   41,   71,   64,   70,   74,   72,
       55,   73,   69,   78,   55,   75,   71,    6,   76,    6,
       46,   74,   70,   78,   79,   79,   75,   77,  286,   46,
       46,   46,   73,   46,  285,   75,   76,   46,   88,   88,
       46,   80,   80,   80,   46,   46,   46,   46,  122,   77,
       81,   81,   82,   82,   83,   83,   85,   85,   87,   87,

       95,   81,  118,   82,   98,   83,   91,   85,  121,   87,
       89,   89,  279,   91,  122,   98,  104,  104,  104,  104,
      121,   95,  106,  106,  118,  106,  111,  111,  119,  106,
      113,  113,  106,  116,  116,  123,  106,  106,  106,  126,
      125,  127,  129,  128,  150,  119,  155,  156,  160,  164,
      159,  123,  125,  126,  186,  150,  165,  129,  166,  187,
      188,  164,  188,  194,  186,  206,  127,  128,  159,  156,
      165,  190,  155,  166,  191,  160,  209,  210,  192,  211,
      213,  190,  212,  187,  191,  192,  214,  215,  221,  224,
      194,  206,  222,  225,  226,  211,  210,  227,  209,  229,

      212,  230,  213,  224,  214,  232,  221,  226,  225,  233,
      236,  237,  215,  240,  238,  222,  241,  244,  227,  230,
      242,  229,  243,  247,  246,  236,  245,  232,  238,  237,
      248,  249,  252,  250,  253,  254,  240,  241,  233,  246,
      245,  242,  258,  244,  255,  259,  243,  250,  247,  257,
      252,  262,  260,  261,  248,  263,  265,  264,  267,  254,
      249,  269,  255,  253,  268,  262,  258,  257,  260,  263,
      259,  264,  261,  270,  265,  267,  272,  271,  268,  273,
      275,  277,  269,  278,  280,  281,  282,  284,  288,  283,
      287,  276,  272,  289,  274,  281,  266,  270,  271,  283,

      278,  256,  280,  251,  239,  273,  275,  277,  287,  235,
      288,  234,  282,  284,  289,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  293,  293,  293,  293,  293,  293,
      293,  293,  293,  294,  294,  294,  294,  294,  294,  294,
      294,  294,  295,  295,  295,  295,  295,  295,  295,  295,
      295,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      297,  297,  297,  297,  297,  297,  297,  297,  297,  298,
      298,  298,  298,  298,  298,  298,  298,  298,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  300,  300,  301,
      301,  301,  301,  301,  301,  301,  301,  301,  302,  302,

      302,  302,  302,  302,  302,  302,  302,  303,  303,  303,
      303,  303,  303,  303,  303,  303,  304,  304,  228,  304,
      223,  304,  304,  305,  305,  305,  218,  305,  305,  305,
      305,  305,  306,  306,  306,  306,  306,  306,  306,  307,
      307,  307,  307,  307,  307,  307,  217,  307,  308,  216,
      308,  308,  308,  308,  308,  308,  308,  309,  208,  309,
      309,  309,  309,  309,  309,  309,  310,  310,  310,  310,
      310,  310,  310,  207,  310,  312,  312,  312,  312,  312,
      312,  205,  312,  312,  200,  198,  196,  195,  193,  189,
      185,  183,  182,  181,  180,  171,  169,  168,  167,  163,

      162,  161,  158,  157,  154,  153,  152,  151,  149,  148,
      147,  146,  143,  142,  141,  140,  139,  137,  133,  132,
      131,  130,  120,  117,  115,  109,  107,  102,  101,  100,
       99,   97,   96,   94,   93,   92,   84,   66,   63,   57,
       47,   37,   24,   23,   22,   19,   18,   17,   12,   11,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int gabc_score_determination__flex_debug;
int gabc_score_determination__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *gabc_score_determination_text;
#line 1 "gabc/gabc-score-determination.l"
#line 2 "gabc/gabc-score-determination.l"
/*
 * Gregorio is a program that translates gabc files to GregorioTeX
 * This file implements the score lexer.
 *
 * Gregorio score determination in gabc input.
 * Copyright (C) 2006-2015 The Gregorio Project (see CONTRIBUTORS.md)
 *
 * This file is part of Gregorio.
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with 
 * this program.  If not, see <http://www.gnu.org/licenses/>. 
 */

#include "config.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "struct.h"
#include "messages.h"
#include "bool.h"
#include "support.h"

#include "gabc.h"
#include "gabc-score-determination.h"
#include "gabc-score-determination-y.h"

static unsigned char style_stack = 0;
static bool eof_found = false;

#define YY_NO_INPUT

#define YY_INPUT(buf,result,max_size) \
    if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) { \
        int c = '*'; \
        size_t n; \
        for (n = 0; n < max_size \
                && (c = getc(gabc_score_determination_in)) != EOF \
                && c != '\n'; ++n ) { \
            buf[n] = (char) c; \
        } \
        if (c == '\n') { \
            buf[n++] = (char) c; \
        } \
        if (c == EOF && ferror(gabc_score_determination_in)) { \
            YY_FATAL_ERROR("input in flex scanner failed"); \
        } \
        result = n; \
    } else { \
        errno=0; \
        while ((result = fread(buf, 1, max_size, gabc_score_determination_in)) \
                == 0 && ferror(gabc_score_determination_in)) { \
            if (errno != EINTR) { \
                YY_FATAL_ERROR("input in flex scanner failed"); \
                break; \
            } \
            errno = 0; \
            clearerr(gabc_score_determination_in); \
        } \
    } \
    gabc_digest(buf, result)

#define YY_USER_ACTION gabc_update_location(&gabc_score_determination_lloc, \
        gabc_score_determination_text, gabc_score_determination_leng);









/* The expression for attribute below is rather messy because we allow
for (a) single-line values, ending with a semicolon at end of line or a
double semicolon, (b) multi-line values, which end at a double
semicolon. */
#line 817 "gabc/gabc-score-determination-l.c"

#define INITIAL 0
#define attribute 1
#define score 2
#define notes 3
#define style 4
#define verb 5
#define comments 6
#define inicomments 7
#define alt 8

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gabc_score_determination_lex_destroy (void );

int gabc_score_determination_get_debug (void );

void gabc_score_determination_set_debug (int debug_flag  );

YY_EXTRA_TYPE gabc_score_determination_get_extra (void );

void gabc_score_determination_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *gabc_score_determination_get_in (void );

void gabc_score_determination_set_in  (FILE * in_str  );

FILE *gabc_score_determination_get_out (void );

void gabc_score_determination_set_out  (FILE * out_str  );

yy_size_t gabc_score_determination_get_leng (void );

char *gabc_score_determination_get_text (void );

int gabc_score_determination_get_lineno (void );

void gabc_score_determination_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gabc_score_determination_wrap (void );
#else
extern int gabc_score_determination_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( gabc_score_determination_text, gabc_score_determination_leng, 1, gabc_score_determination_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gabc_score_determination_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gabc_score_determination_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gabc_score_determination_in))==0 && ferror(gabc_score_determination_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gabc_score_determination_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gabc_score_determination_lex (void);

#define YY_DECL int gabc_score_determination_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gabc_score_determination_text and gabc_score_determination_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( gabc_score_determination_leng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(gabc_score_determination_text[gabc_score_determination_leng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gabc_score_determination_in )
			gabc_score_determination_in = stdin;

		if ( ! gabc_score_determination_out )
			gabc_score_determination_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gabc_score_determination_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gabc_score_determination__create_buffer(gabc_score_determination_in,YY_BUF_SIZE );
		}

		gabc_score_determination__load_buffer_state( );
		}

	{
#line 108 "gabc/gabc-score-determination.l"

#line 1041 "gabc/gabc-score-determination-l.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of gabc_score_determination_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 292 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 651 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 109 "gabc/gabc-score-determination.l"
{
        /* BOM written by a lot of windows softwares when they write UTF-8 */
    }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 112 "gabc/gabc-score-determination.l"
{
        /* ignoring empty lines */
    }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 115 "gabc/gabc-score-determination.l"
{
        BEGIN(inicomments);
    }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 118 "gabc/gabc-score-determination.l"
{
        BEGIN(INITIAL);
    }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 121 "gabc/gabc-score-determination.l"
{
        /* ignored */
    }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 124 "gabc/gabc-score-determination.l"
{
        BEGIN(attribute);
        return COLON;
    }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 128 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ATTRIBUTE;
    }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 133 "gabc/gabc-score-determination.l"
{
         BEGIN(INITIAL);
         return SEMICOLON;
    }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 137 "gabc/gabc-score-determination.l"
{
         gabc_score_determination_lval.character = gabc_score_determination_text[5];
         return DEF_MACRO;
    }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 141 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
         return NAME;
    }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 146 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return SCORE_COPYRIGHT;
    }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 151 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return GABC_COPYRIGHT;
    }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 156 "gabc/gabc-score-determination.l"
{
        /* DEPRECATED by 4.1 */
        return INITIAL_STYLE;
    }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 160 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE;
    }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 165 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE_MODIFIER;
    }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 170 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return MODE_DIFFERENTIA;
    }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 175 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ANNOTATION;
    }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 180 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return AUTHOR;
    }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 185 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return LANGUAGE;
    }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 190 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return STAFF_LINES;
    }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 195 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return NABC_LINES;
    }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 200 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return ORISCUS_ORIENTATION;
    }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 205 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return OTHER_HEADER;
    }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 210 "gabc/gabc-score-determination.l"
{
       BEGIN(score);
       return END_OF_DEFINITIONS;
    }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 214 "gabc/gabc-score-determination.l"
{
        gregorio_messagef("det_score", VERBOSITY_ERROR, 0,
                _("unrecognized character: \"%c\" in definition part"),
                gabc_score_determination_text[0]);
    }
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 219 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return CHARACTERS;
    }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 224 "gabc/gabc-score-determination.l"
{
        return HYPHEN;
    }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 227 "gabc/gabc-score-determination.l"
{
        return NLBA_B;
    }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 230 "gabc/gabc-score-determination.l"
{
        return NLBA_E;
    }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 233 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return I_BEGIN;
    }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 238 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return I_END;
    }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 245 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return TT_BEGIN;
    }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 250 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return TT_END;
    }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 257 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return UL_BEGIN;
    }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 262 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return UL_END;
    }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 269 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return C_BEGIN;
    }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 274 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return C_END;
    }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 281 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return B_BEGIN;
    }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 286 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return B_END;
    }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 293 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return SC_BEGIN;
    }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 298 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return SC_END;
    }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 305 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return ELISION_BEGIN;
    }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 310 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return ELISION_END;
    }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 317 "gabc/gabc-score-determination.l"
{
        BEGIN(style);
        style_stack ++;
        return SP_BEGIN;
    }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 322 "gabc/gabc-score-determination.l"
{
        style_stack --;
        if (style_stack == 0) {
            BEGIN(score);
        }
        return SP_END;
    }
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 329 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return CHARACTERS;
    }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 334 "gabc/gabc-score-determination.l"
{
        BEGIN(comments);
    }
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 337 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
    }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 340 "gabc/gabc-score-determination.l"
{
        /* ignored */
    }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 343 "gabc/gabc-score-determination.l"
{
        BEGIN(verb);
        return VERB_BEGIN;
    }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 347 "gabc/gabc-score-determination.l"
{
        if (style_stack == 0) {
            BEGIN(score);
        } else {
            BEGIN(style);
        }
        return VERB_END;
    }
	YY_BREAK
case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
#line 355 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return CHARACTERS;
    }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 360 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return CHARACTERS;
    }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 365 "gabc/gabc-score-determination.l"
{
        return CENTER_BEGIN;
    }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 368 "gabc/gabc-score-determination.l"
{
        return CENTER_END;
    }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 371 "gabc/gabc-score-determination.l"
{
        BEGIN(alt);
        return ALT_BEGIN;
    }
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 375 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return CHARACTERS;
    }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 380 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return ALT_END;
    }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 384 "gabc/gabc-score-determination.l"
{
        return EUOUAE_B;
    }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 387 "gabc/gabc-score-determination.l"
{
        return EUOUAE_E;
    }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 390 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_CENTER_END;
    }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 393 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_BEGIN;
    }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 396 "gabc/gabc-score-determination.l"
{
        return TRANSLATION_END;
    }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 399 "gabc/gabc-score-determination.l"
{
        BEGIN(notes);
        return OPENING_BRACKET;
    }
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 403 "gabc/gabc-score-determination.l"
{
        gabc_score_determination_lval.text =
                gregorio_strdup(gabc_score_determination_text);
        return NOTES;
    }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 408 "gabc/gabc-score-determination.l"
{
        return NABC_CUT;
    }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 411 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return CLOSING_BRACKET;
    }
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 415 "gabc/gabc-score-determination.l"
{
        BEGIN(score);
        return CLOSING_BRACKET_WITH_SPACE;
    }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(attribute):
case YY_STATE_EOF(score):
case YY_STATE_EOF(notes):
case YY_STATE_EOF(style):
case YY_STATE_EOF(verb):
case YY_STATE_EOF(comments):
case YY_STATE_EOF(inicomments):
case YY_STATE_EOF(alt):
#line 419 "gabc/gabc-score-determination.l"
{
        if (!eof_found) {
            eof_found = true;
            return END_OF_FILE;
        } else {
            yyterminate();
        }
    }
	YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
#line 427 "gabc/gabc-score-determination.l"
{
        gregorio_messagef("gabc_score_determination_lex", VERBOSITY_ERROR, 0,
                _("unrecognized character: \"%c\""),
                gabc_score_determination_text[0]);
    }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 432 "gabc/gabc-score-determination.l"
ECHO;
	YY_BREAK
#line 1727 "gabc/gabc-score-determination-l.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gabc_score_determination_in at a new source and called
			 * gabc_score_determination_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gabc_score_determination_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gabc_score_determination_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gabc_score_determination_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of gabc_score_determination_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					gabc_score_determination_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gabc_score_determination_restart(gabc_score_determination_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gabc_score_determination_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 292 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 292 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 291);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gabc_score_determination_restart(gabc_score_determination_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gabc_score_determination_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gabc_score_determination_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gabc_score_determination_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gabc_score_determination_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gabc_score_determination__create_buffer(gabc_score_determination_in,YY_BUF_SIZE );
	}

	gabc_score_determination__init_buffer(YY_CURRENT_BUFFER,input_file );
	gabc_score_determination__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gabc_score_determination__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gabc_score_determination_pop_buffer_state();
	 *		gabc_score_determination_push_buffer_state(new_buffer);
     */
	gabc_score_determination_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gabc_score_determination__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gabc_score_determination_wrap()) processing, but the only time this flag
	 * is looked at is after gabc_score_determination_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gabc_score_determination__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gabc_score_determination_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gabc_score_determination__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gabc_score_determination_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gabc_score_determination_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination__create_buffer()" );

	b->yy_is_our_buffer = 1;

	gabc_score_determination__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gabc_score_determination__create_buffer()
 * 
 */
    void gabc_score_determination__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gabc_score_determination_free((void *) b->yy_ch_buf  );

	gabc_score_determination_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gabc_score_determination_restart() or at EOF.
 */
    static void gabc_score_determination__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gabc_score_determination__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gabc_score_determination__init_buffer was _probably_
     * called from gabc_score_determination_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gabc_score_determination__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gabc_score_determination__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gabc_score_determination_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gabc_score_determination_ensure_buffer_stack();

	/* This block is copied from gabc_score_determination__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gabc_score_determination__switch_to_buffer. */
	gabc_score_determination__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gabc_score_determination_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gabc_score_determination__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gabc_score_determination__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gabc_score_determination_ensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)gabc_score_determination_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gabc_score_determination_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gabc_score_determination__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gabc_score_determination_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gabc_score_determination__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gabc_score_determination_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gabc_score_determination__scan_bytes() instead.
 */
YY_BUFFER_STATE gabc_score_determination__scan_string (yyconst char * yystr )
{
    
	return gabc_score_determination__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gabc_score_determination_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gabc_score_determination__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gabc_score_determination_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gabc_score_determination__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gabc_score_determination__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gabc_score_determination__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gabc_score_determination_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gabc_score_determination_text[gabc_score_determination_leng] = (yy_hold_char); \
		(yy_c_buf_p) = gabc_score_determination_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gabc_score_determination_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gabc_score_determination_get_lineno  (void)
{
        
    return gabc_score_determination_lineno;
}

/** Get the input stream.
 * 
 */
FILE *gabc_score_determination_get_in  (void)
{
        return gabc_score_determination_in;
}

/** Get the output stream.
 * 
 */
FILE *gabc_score_determination_get_out  (void)
{
        return gabc_score_determination_out;
}

/** Get the length of the current token.
 * 
 */
yy_size_t gabc_score_determination_get_leng  (void)
{
        return gabc_score_determination_leng;
}

/** Get the current token.
 * 
 */

char *gabc_score_determination_get_text  (void)
{
        return gabc_score_determination_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void gabc_score_determination_set_lineno (int  line_number )
{
    
    gabc_score_determination_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see gabc_score_determination__switch_to_buffer
 */
void gabc_score_determination_set_in (FILE *  in_str )
{
        gabc_score_determination_in = in_str ;
}

void gabc_score_determination_set_out (FILE *  out_str )
{
        gabc_score_determination_out = out_str ;
}

int gabc_score_determination_get_debug  (void)
{
        return gabc_score_determination__flex_debug;
}

void gabc_score_determination_set_debug (int  bdebug )
{
        gabc_score_determination__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gabc_score_determination_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    gabc_score_determination_in = stdin;
    gabc_score_determination_out = stdout;
#else
    gabc_score_determination_in = (FILE *) 0;
    gabc_score_determination_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gabc_score_determination_lex_init()
     */
    return 0;
}

/* gabc_score_determination_lex_destroy is for both reentrant and non-reentrant scanners. */
int gabc_score_determination_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gabc_score_determination__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gabc_score_determination_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	gabc_score_determination_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        gabc_score_determination_free((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gabc_score_determination_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gabc_score_determination_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *gabc_score_determination_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gabc_score_determination_free (void * ptr )
{
	free( (char *) ptr );	/* see gabc_score_determination_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 432 "gabc/gabc-score-determination.l"




